"""
Created on 19 Nov 2017

@author: Bruno Beloff (bruno.beloff@southcoastscience.com)
"""

import optparse

from scs_philips_hue import version


# --------------------------------------------------------------------------------------------------------------------

class CmdChannelTest(object):
    """unix command line handler"""

    def __init__(self):
        """
        Constructor
        """
        self.__parser = optparse.OptionParser(usage="%prog -c CHANNEL [-i INTERVAL] [-f] [-v]", version=version())

        # input...
        self.__parser.add_option("--channel", "-c", type="string", action="store", dest="channel",
                                 help="the name of the information channel")

        # operation...
        self.__parser.add_option("--transition-time", "-t", type="int", action="store", dest="transition_time",
                                 help="override chroma conf transition time")

        self.__parser.add_option("--forever", "-f", action="store_true", dest="forever", default=False,
                                 help="run until Control-C")

        # output...
        self.__parser.add_option("--verbose", "-v", action="store_true", dest="verbose", default=False,
                                 help="report narrative to stderr")

        self.__opts, self.__args = self.__parser.parse_args()


    # ----------------------------------------------------------------------------------------------------------------

    def is_valid(self):
        if self.channel is None:
            return False

        return True


    # ----------------------------------------------------------------------------------------------------------------

    @property
    def channel(self):
        return self.__opts.channel


    @property
    def transition_time(self):
        return self.__opts.transition_time


    @property
    def forever(self):
        return self.__opts.forever


    @property
    def verbose(self):
        return self.__opts.verbose


    # ----------------------------------------------------------------------------------------------------------------

    def print_help(self, file):
        self.__parser.print_help(file)


    def __str__(self, *args, **kwargs):
        return "CmdChannelTest:{channel:%s, transition_time:%s, forever:%s, verbose:%s}" %  \
            (self.channel, self.transition_time, self.forever, self.verbose)



"""
Created on 30 Oct 2017

@author: Bruno Beloff (bruno.beloff@southcoastscience.com)
"""

from scs_core.sys.logging import Logging

from scs_philips_hue.client.upnp_client import UPnPClient
from scs_philips_hue.data.bridge.bridge_summary import BridgeSummary


# --------------------------------------------------------------------------------------------------------------------

class UPnPDiscovery(object):
    """
    classdocs
    """

    # ----------------------------------------------------------------------------------------------------------------

    def __init__(self):
        """
        Constructor
        """
        self.__upnp_client = UPnPClient()
        self.__logger = Logging.getLogger()


    # ----------------------------------------------------------------------------------------------------------------

    def find(self, id):
        descriptions = self.find_all()

        for description in descriptions:
            self.__logger.info("found: %s" % description)

            if description.id.lower() == id.lower():
                return description

        return None


    def find_all(self):
        # request...
        try:
            self.__upnp_client.connect()
            response_jdict = self.__upnp_client.get()

        finally:
            self.__upnp_client.close()

        # response...
        return tuple(BridgeSummary.construct_from_jdict(jdict) for jdict in response_jdict)


    # ----------------------------------------------------------------------------------------------------------------

    def __str__(self, *args, **kwargs):
        return "UPnPDiscovery:{upnp_client:%s}" % self.__upnp_client



#!/usr/bin/env python3

"""
Created on 1 Dec 2024

@author: Bruno Beloff (bruno.beloff@southcoastscience.com)

source repo: scs_philips_hue

DESCRIPTION
The channel_test utility is used to test both the channel chroma conf and desk configuration - both must be
configured before using this utility.

SYNOPSIS
channel_test.py -c CHANNEL [-i INTERVAL] [-f] [-v]

EXAMPLES
./channel_test.py -v -c channel-1 -t 2 -f | ./desk.py -v

DOCUMENT EXAMPLE - OUTPUT
{"channel-1": {"bri": 254, "transitiontime": 20, "xy": [0.05, 0.5]}}
...

SEE ALSO
scs_philips_hue/chroma_conf
scs_philips_hue/desk
scs_philips_hue/desk_conf

RESOURCES
https://en.wikipedia.org/wiki/Chromaticity
"""

import sys
import time

from scs_core.data.json import JSONify
from scs_core.sys.logging import Logging

from scs_host.sys.host import Host

from scs_philips_hue.cmd.cmd_channel_test import CmdChannelTest

from scs_philips_hue.config.chroma_conf import ChromaConfSet

from scs_philips_hue.data.light.chroma import ChromaPoint
from scs_philips_hue.data.light.light_state import LightState


# --------------------------------------------------------------------------------------------------------------------

def print_state(state, pause):
    print(JSONify.dumps({cmd.channel: state}))
    sys.stdout.flush()

    time.sleep(transition_time + pause)


# --------------------------------------------------------------------------------------------------------------------

if __name__ == '__main__':

    # ----------------------------------------------------------------------------------------------------------------
    # cmd...

    cmd = CmdChannelTest()

    Logging.config('channel_test', verbose=cmd.verbose)
    logger = Logging.getLogger()

    logger.info(cmd)

    try:
        # ------------------------------------------------------------------------------------------------------------
        # resources...

        # ChromaConf...
        chroma_confs = ChromaConfSet.load(Host)

        if chroma_confs is None:
            logger.error("ChromaConfSet not available.")
            exit(1)

        logger.info(chroma_confs)

        chroma_conf = chroma_confs.conf(cmd.channel)

        if chroma_conf is None:
            logger.error("ChromaConf not available for channel '%s'." % cmd.channel)
            exit(1)

        logger.info(chroma_conf)

        path = chroma_conf.path()
        logger.info(path)

        brightness = chroma_conf.brightness
        transition_time = chroma_conf.transition_time if cmd.transition_time is None else cmd.transition_time


        # ------------------------------------------------------------------------------------------------------------
        # run...

        while True:
            # path points...
            for point in path.points:
                print_state(LightState(bri=brightness, xy=point, transition_time=transition_time), 1)

            if not cmd.forever:
                break

            # white interval...
            print_state(LightState(bri=brightness, xy=ChromaPoint.white_3000k(), transition_time=transition_time), 3)


    # ----------------------------------------------------------------------------------------------------------------
    # end...

    except KeyboardInterrupt:
        print(file=sys.stderr)
